@@ -5,6 +5,8 @@ import threading
 import concurrent.futures
 import gc
 import math
+import sys
+import pkg_resources
 import numpy as np
 import multiprocessing as mp
 
@@ -607,7 +609,7 @@ class Predictor(Singleton):
         else:
             if os.path.exists(audio_file_path):
                 os.remove(audio_file_path)
-            raise TerminalException("Error: No subtitles passed in")
+            raise TerminalException("ERROR: No subtitles passed in")
         with self.__lock:
             try:
                 train_data, labels = self.__feature_embedder.extract_data_and_label_from_audio(
@@ -646,7 +648,7 @@ class Predictor(Singleton):
             if os.path.exists(audio_file_path):
                 os.remove(audio_file_path)
             raise TerminalException(
-                "Error: Audio is too short and no voice was detected"
+                "ERROR: Audio is too short and no voice was detected"
             )
 
         result["time_predictions"] = str(datetime.datetime.now() - pred_start)
@@ -679,7 +681,7 @@ class Predictor(Singleton):
         else:
             if os.path.exists(audio_file_path):
                 os.remove(audio_file_path)
-            raise ValueError("Error: No subtitles passed in")
+            raise ValueError("ERROR: No subtitles passed in")
 
         if abs(seconds_to_shift) > Predictor.__MAX_SHIFT_IN_SECS:
             if os.path.exists(audio_file_path):
