@@ -10,10 +10,10 @@ optional arguments:
   -h, --help            show this help message and exit
   -l MAX_LOGLOSS, --max_logloss MAX_LOGLOSS
                         Max global log loss for alignment
-  -so, --stretch_off    Switch off stretch on subtitles for non-English speech
+  -so, --stretch_on    Switch on stretch on subtitles
   -sil {afr,amh,ara,arg,asm,aze,ben,bos,bul,cat,ces,cmn,cym,dan,deu,ell,eng,epo,est,eus,fas,fin,fra,gla,gle,glg,grc,grn,guj,heb,hin,hrv,hun,hye,ina,ind,isl,ita,jbo,jpn,kal,kan,kat,kir,kor,kur,lat,lav,lfn,lit,mal,mar,mkd,mlt,msa,mya,nah,nep,nld,nor,ori,orm,pan,pap,pol,por,ron,rus,sin,slk,slv,spa,sqi,srp,swa,swe,tam,tat,tel,tha,tsn,tur,ukr,urd,vie,yue,zho}, --stretch_in_language {afr,amh,ara,arg,asm,aze,ben,bos,bul,cat,ces,cmn,cym,dan,deu,ell,eng,epo,est,eus,fas,fin,fra,gla,gle,glg,grc,grn,guj,heb,hin,hrv,hun,hye,ina,ind,isl,ita,jbo,jpn,kal,kan,kat,kir,kor,kur,lat,lav,lfn,lit,mal,mar,mkd,mlt,msa,mya,nah,nep,nld,nor,ori,orm,pan,pap,pol,por,ron,rus,sin,slk,slv,spa,sqi,srp,swa,swe,tam,tat,tel,tha,tsn,tur,ukr,urd,vie,yue,zho}
                         Stretch the subtitle with the supported ISO 639-3 language code [https://en.wikipedia.org/wiki/List_of_ISO_639-3_codes].
-                        NB: This will be ignored if either -so or --stretch_off is present
+                        NB: This will be ignored if neither -so nor --stretch_on is present
   -fos, --exit_segfail  Exit on any segment alignment failures
   -tod TRAINING_OUTPUT_DIRECTORY, --training_output_directory TRAINING_OUTPUT_DIRECTORY
                         Path to the output directory containing training results
@@ -38,16 +38,17 @@ import sys
 import traceback
 import os
 import tempfile
+import pkg_resources
 
 
 def main():
     if sys.version_info.major != 3:
-        print("Cannot find Python 3")
+        print("ERROR: Cannot find Python 3")
         sys.exit(20)
     try:
         import subaligner
     except ModuleNotFoundError:
-        print("Subaligner is not installed")
+        print("ERROR: Subaligner is not installed")
         sys.exit(20)
 
     from subaligner._version import __version__
@@ -77,9 +78,9 @@ def main():
     )
     parser.add_argument(
         "-so",
-        "--stretch_off",
+        "--stretch_on",
         action="store_true",
-        help="Switch off stretch on subtitles for non-English speech",
+        help="Switch on stretch on subtitles",
     )
     from subaligner.utils import Utils
     parser.add_argument(
@@ -88,7 +89,7 @@ def main():
         type=str,
         choices=Utils.get_stretch_language_codes(),
         default="eng",
-        help="Stretch the subtitle with the supported ISO 639-3 language code [https://en.wikipedia.org/wiki/List_of_ISO_639-3_codes].\nNB: This will be ignored if either -so or --stretch_off is present",
+        help="Stretch the subtitle with the supported ISO 639-3 language code [https://en.wikipedia.org/wiki/List_of_ISO_639-3_codes].\nNB: This will be ignored if neither -so nor --stretch_on is present",
     )
     parser.add_argument(
         "-fos",
@@ -129,33 +130,40 @@ def main():
         print("\n".join(Utils.get_language_table()))
         sys.exit(0)
     if FLAGS.video_path == "":
-        print("--video_path was not passed in")
+        print("ERROR: --video_path was not passed in")
         parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path == "":
-        print("--subtitle_path was not passed in")
+        print("ERROR: --subtitle_path was not passed in")
         parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path.lower().startswith("http") and FLAGS.output == "":
-        print("--output was not passed in for alignment on a remote subtitle file")
+        print("ERROR: --output was not passed in for alignment on a remote subtitle file")
         parser.print_usage()
         sys.exit(21)
     if FLAGS.subtitle_path.lower().startswith("teletext:") and FLAGS.output == "":
-        print("--output was not passed in for alignment on embedded subtitles")
+        print("ERROR: --output was not passed in for alignment on embedded subtitles")
         parser.print_usage()
         sys.exit(21)
+    if FLAGS.translate is not None:
+        if "transformers" not in {pkg.key for pkg in pkg_resources.working_set}:
+            print('ERROR: Alignment has been configured to perform translation. Please install "subaligner[translation]" and run your command again.')
+            sys.exit(21)
+    if FLAGS.stretch_on:
+        if "aeneas" not in {pkg.key for pkg in pkg_resources.working_set}:
+            print('ERROR: Alignment has been configured to use extra features. Please install "subaligner[stretch]" and run your command again.')
+            sys.exit(21)
 
     local_video_path = FLAGS.video_path
     local_subtitle_path = FLAGS.subtitle_path
     exit_segfail = FLAGS.exit_segfail
-    stretch = not FLAGS.stretch_off
+    stretch = FLAGS.stretch_on
     stretch_in_lang = FLAGS.stretch_in_language
 
     from subaligner.logger import Logger
     Logger.VERBOSE = FLAGS.debug
     Logger.QUIET = FLAGS.quiet
     from subaligner.predictor import Predictor
-    from subaligner.translator import Translator
     from subaligner.exception import UnsupportedFormatException
     from subaligner.exception import TerminalException
 
@@ -184,7 +192,7 @@ def main():
                 elif "stream_index" in params:
                     Utils.extract_matroska_subtitle(local_video_path, int(params["stream_index"]), local_subtitle_path)
             else:
-                print("Embedded subtitle selector cannot be empty")
+                print("ERROR: Embedded subtitle selector cannot be empty")
                 parser.print_usage()
                 sys.exit(21)
 
@@ -202,6 +210,7 @@ def main():
             FLAGS.subtitle_path.rsplit(".", 1)).replace(".stl", ".srt") if FLAGS.output == "" else FLAGS.output
 
         if FLAGS.translate is not None:
+            from subaligner.translator import Translator
             source, target = FLAGS.translate.split(",")
             translator = Translator(source, target)
             subs_list = translator.translate(subs)
@@ -212,7 +221,7 @@ def main():
         log_loss = predictor.get_log_loss(voice_probabilities, subs_list)
         if log_loss is None or log_loss > FLAGS.max_logloss:
             print(
-                "Alignment failed with a too high loss value: {}".format(log_loss)
+                "ERROR: Alignment failed with a too high loss value: {}".format(log_loss)
             )
             _remove_tmp_files(FLAGS, local_video_path, local_subtitle_path)
             sys.exit(22)
@@ -220,21 +229,21 @@ def main():
         print("Aligned subtitle saved to: {}".format(aligned_subtitle_path))
     except UnsupportedFormatException as e:
         print(
-            "{}\n{}".format(str(e), "".join(traceback.format_stack()) if FLAGS.debug else "")
+            "ERROR: {}\n{}".format(str(e), "".join(traceback.format_stack()) if FLAGS.debug else "")
         )
         traceback.print_tb(e.__traceback__)
         _remove_tmp_files(FLAGS, local_video_path, local_subtitle_path)
         sys.exit(23)
     except TerminalException as e:
         print(
-            "{}\n{}".format(str(e), "".join(traceback.format_stack()) if FLAGS.debug else "")
+            "ERROR: {}\n{}".format(str(e), "".join(traceback.format_stack()) if FLAGS.debug else "")
         )
         traceback.print_tb(e.__traceback__)
         _remove_tmp_files(FLAGS, local_video_path, local_subtitle_path)
         sys.exit(24)
     except Exception as e:
         print(
-            "{}\n{}".format(str(e), "".join(traceback.format_stack()) if FLAGS.debug else "")
+            "ERROR: {}\n{}".format(str(e), "".join(traceback.format_stack()) if FLAGS.debug else "")
         )
         traceback.print_tb(e.__traceback__)
         _remove_tmp_files(FLAGS, local_video_path, local_subtitle_path)
